Class: Google::Cloud::Talent::V4beta1::SearchJobsResponse
- Inherits:
-
Object
- Object
- Google::Cloud::Talent::V4beta1::SearchJobsResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/talent/v4beta1/job_service.rb
Overview
Response for SearchJob method.
Defined Under Namespace
Classes: CommuteInfo, MatchingJob
Instance Attribute Summary collapse
-
#broadened_query_jobs_count ⇒ ::Integer
If query broadening is enabled, we may append additional results from the broadened query.
-
#estimated_total_size ⇒ ::Integer
An estimation of the number of jobs that match the specified query.
-
#histogram_query_results ⇒ ::Array<::Google::Cloud::Talent::V4beta1::HistogramQueryResult>
The histogram results that match with specified SearchJobsRequest.histogram_queries.
-
#location_filters ⇒ ::Array<::Google::Cloud::Talent::V4beta1::Location>
The location filters that the service applied to the specified query.
-
#matching_jobs ⇒ ::Array<::Google::Cloud::Talent::V4beta1::SearchJobsResponse::MatchingJob>
The Job entities that match the specified SearchJobsRequest.
-
#metadata ⇒ ::Google::Cloud::Talent::V4beta1::ResponseMetadata
Additional information for the API invocation, such as the request tracking id.
-
#next_page_token ⇒ ::String
The token that specifies the starting position of the next page of results.
-
#spell_correction ⇒ ::Google::Cloud::Talent::V4beta1::SpellingCorrection
The spell checking result, and correction.
-
#total_size ⇒ ::Integer
The precise result count with limit 100,000.
Instance Attribute Details
#broadened_query_jobs_count ⇒ ::Integer
Returns If query broadening is enabled, we may append additional results from the broadened query. This number indicates how many of the jobs returned in the jobs field are from the broadened query. These results are always at the end of the jobs list. In particular, a value of 0, or if the field isn't set, all the jobs in the jobs list are from the original (without broadening) query. If this field is non-zero, subsequent requests with offset after this result set should contain all broadened results.
731 732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 |
# File 'proto_docs/google/cloud/talent/v4beta1/job_service.rb', line 731 class SearchJobsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Job entry with metadata inside # {::Google::Cloud::Talent::V4beta1::SearchJobsResponse SearchJobsResponse}. # @!attribute [rw] job # @return [::Google::Cloud::Talent::V4beta1::Job] # Job resource that matches the specified # {::Google::Cloud::Talent::V4beta1::SearchJobsRequest SearchJobsRequest}. # @!attribute [rw] job_summary # @return [::String] # A summary of the job with core information that's displayed on the search # results listing page. # @!attribute [rw] job_title_snippet # @return [::String] # Contains snippets of text from the # {::Google::Cloud::Talent::V4beta1::Job#title Job.title} field most closely # matching a search query's keywords, if available. The matching query # keywords are enclosed in HTML bold tags. # @!attribute [rw] search_text_snippet # @return [::String] # Contains snippets of text from the # {::Google::Cloud::Talent::V4beta1::Job#description Job.description} and # similar fields that most closely match a search query's keywords, if # available. All HTML tags in the original fields are stripped when # returned in this field, and matching query keywords are enclosed in HTML # bold tags. # @!attribute [rw] commute_info # @return [::Google::Cloud::Talent::V4beta1::SearchJobsResponse::CommuteInfo] # Commute information which is generated based on specified # {::Google::Cloud::Talent::V4beta1::CommuteFilter CommuteFilter}. class MatchingJob include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Commute details related to this job. # @!attribute [rw] job_location # @return [::Google::Cloud::Talent::V4beta1::Location] # Location used as the destination in the commute calculation. # @!attribute [rw] travel_duration # @return [::Google::Protobuf::Duration] # The number of seconds required to travel to the job location from the # query location. A duration of 0 seconds indicates that the job isn't # reachable within the requested duration, but was returned as part of an # expanded query. class CommuteInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#estimated_total_size ⇒ ::Integer
Returns An estimation of the number of jobs that match the specified query.
This number isn't guaranteed to be accurate. For accurate results, see SearchJobsResponse.total_size.
731 732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 |
# File 'proto_docs/google/cloud/talent/v4beta1/job_service.rb', line 731 class SearchJobsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Job entry with metadata inside # {::Google::Cloud::Talent::V4beta1::SearchJobsResponse SearchJobsResponse}. # @!attribute [rw] job # @return [::Google::Cloud::Talent::V4beta1::Job] # Job resource that matches the specified # {::Google::Cloud::Talent::V4beta1::SearchJobsRequest SearchJobsRequest}. # @!attribute [rw] job_summary # @return [::String] # A summary of the job with core information that's displayed on the search # results listing page. # @!attribute [rw] job_title_snippet # @return [::String] # Contains snippets of text from the # {::Google::Cloud::Talent::V4beta1::Job#title Job.title} field most closely # matching a search query's keywords, if available. The matching query # keywords are enclosed in HTML bold tags. # @!attribute [rw] search_text_snippet # @return [::String] # Contains snippets of text from the # {::Google::Cloud::Talent::V4beta1::Job#description Job.description} and # similar fields that most closely match a search query's keywords, if # available. All HTML tags in the original fields are stripped when # returned in this field, and matching query keywords are enclosed in HTML # bold tags. # @!attribute [rw] commute_info # @return [::Google::Cloud::Talent::V4beta1::SearchJobsResponse::CommuteInfo] # Commute information which is generated based on specified # {::Google::Cloud::Talent::V4beta1::CommuteFilter CommuteFilter}. class MatchingJob include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Commute details related to this job. # @!attribute [rw] job_location # @return [::Google::Cloud::Talent::V4beta1::Location] # Location used as the destination in the commute calculation. # @!attribute [rw] travel_duration # @return [::Google::Protobuf::Duration] # The number of seconds required to travel to the job location from the # query location. A duration of 0 seconds indicates that the job isn't # reachable within the requested duration, but was returned as part of an # expanded query. class CommuteInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#histogram_query_results ⇒ ::Array<::Google::Cloud::Talent::V4beta1::HistogramQueryResult>
Returns The histogram results that match with specified SearchJobsRequest.histogram_queries.
731 732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 |
# File 'proto_docs/google/cloud/talent/v4beta1/job_service.rb', line 731 class SearchJobsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Job entry with metadata inside # {::Google::Cloud::Talent::V4beta1::SearchJobsResponse SearchJobsResponse}. # @!attribute [rw] job # @return [::Google::Cloud::Talent::V4beta1::Job] # Job resource that matches the specified # {::Google::Cloud::Talent::V4beta1::SearchJobsRequest SearchJobsRequest}. # @!attribute [rw] job_summary # @return [::String] # A summary of the job with core information that's displayed on the search # results listing page. # @!attribute [rw] job_title_snippet # @return [::String] # Contains snippets of text from the # {::Google::Cloud::Talent::V4beta1::Job#title Job.title} field most closely # matching a search query's keywords, if available. The matching query # keywords are enclosed in HTML bold tags. # @!attribute [rw] search_text_snippet # @return [::String] # Contains snippets of text from the # {::Google::Cloud::Talent::V4beta1::Job#description Job.description} and # similar fields that most closely match a search query's keywords, if # available. All HTML tags in the original fields are stripped when # returned in this field, and matching query keywords are enclosed in HTML # bold tags. # @!attribute [rw] commute_info # @return [::Google::Cloud::Talent::V4beta1::SearchJobsResponse::CommuteInfo] # Commute information which is generated based on specified # {::Google::Cloud::Talent::V4beta1::CommuteFilter CommuteFilter}. class MatchingJob include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Commute details related to this job. # @!attribute [rw] job_location # @return [::Google::Cloud::Talent::V4beta1::Location] # Location used as the destination in the commute calculation. # @!attribute [rw] travel_duration # @return [::Google::Protobuf::Duration] # The number of seconds required to travel to the job location from the # query location. A duration of 0 seconds indicates that the job isn't # reachable within the requested duration, but was returned as part of an # expanded query. class CommuteInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#location_filters ⇒ ::Array<::Google::Cloud::Talent::V4beta1::Location>
Returns The location filters that the service applied to the specified query. If any filters are lat-lng based, the Location.location_type is Location.LocationType.LOCATION_TYPE_UNSPECIFIED.
731 732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 |
# File 'proto_docs/google/cloud/talent/v4beta1/job_service.rb', line 731 class SearchJobsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Job entry with metadata inside # {::Google::Cloud::Talent::V4beta1::SearchJobsResponse SearchJobsResponse}. # @!attribute [rw] job # @return [::Google::Cloud::Talent::V4beta1::Job] # Job resource that matches the specified # {::Google::Cloud::Talent::V4beta1::SearchJobsRequest SearchJobsRequest}. # @!attribute [rw] job_summary # @return [::String] # A summary of the job with core information that's displayed on the search # results listing page. # @!attribute [rw] job_title_snippet # @return [::String] # Contains snippets of text from the # {::Google::Cloud::Talent::V4beta1::Job#title Job.title} field most closely # matching a search query's keywords, if available. The matching query # keywords are enclosed in HTML bold tags. # @!attribute [rw] search_text_snippet # @return [::String] # Contains snippets of text from the # {::Google::Cloud::Talent::V4beta1::Job#description Job.description} and # similar fields that most closely match a search query's keywords, if # available. All HTML tags in the original fields are stripped when # returned in this field, and matching query keywords are enclosed in HTML # bold tags. # @!attribute [rw] commute_info # @return [::Google::Cloud::Talent::V4beta1::SearchJobsResponse::CommuteInfo] # Commute information which is generated based on specified # {::Google::Cloud::Talent::V4beta1::CommuteFilter CommuteFilter}. class MatchingJob include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Commute details related to this job. # @!attribute [rw] job_location # @return [::Google::Cloud::Talent::V4beta1::Location] # Location used as the destination in the commute calculation. # @!attribute [rw] travel_duration # @return [::Google::Protobuf::Duration] # The number of seconds required to travel to the job location from the # query location. A duration of 0 seconds indicates that the job isn't # reachable within the requested duration, but was returned as part of an # expanded query. class CommuteInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#matching_jobs ⇒ ::Array<::Google::Cloud::Talent::V4beta1::SearchJobsResponse::MatchingJob>
Returns The Job entities that match the specified SearchJobsRequest.
731 732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 |
# File 'proto_docs/google/cloud/talent/v4beta1/job_service.rb', line 731 class SearchJobsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Job entry with metadata inside # {::Google::Cloud::Talent::V4beta1::SearchJobsResponse SearchJobsResponse}. # @!attribute [rw] job # @return [::Google::Cloud::Talent::V4beta1::Job] # Job resource that matches the specified # {::Google::Cloud::Talent::V4beta1::SearchJobsRequest SearchJobsRequest}. # @!attribute [rw] job_summary # @return [::String] # A summary of the job with core information that's displayed on the search # results listing page. # @!attribute [rw] job_title_snippet # @return [::String] # Contains snippets of text from the # {::Google::Cloud::Talent::V4beta1::Job#title Job.title} field most closely # matching a search query's keywords, if available. The matching query # keywords are enclosed in HTML bold tags. # @!attribute [rw] search_text_snippet # @return [::String] # Contains snippets of text from the # {::Google::Cloud::Talent::V4beta1::Job#description Job.description} and # similar fields that most closely match a search query's keywords, if # available. All HTML tags in the original fields are stripped when # returned in this field, and matching query keywords are enclosed in HTML # bold tags. # @!attribute [rw] commute_info # @return [::Google::Cloud::Talent::V4beta1::SearchJobsResponse::CommuteInfo] # Commute information which is generated based on specified # {::Google::Cloud::Talent::V4beta1::CommuteFilter CommuteFilter}. class MatchingJob include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Commute details related to this job. # @!attribute [rw] job_location # @return [::Google::Cloud::Talent::V4beta1::Location] # Location used as the destination in the commute calculation. # @!attribute [rw] travel_duration # @return [::Google::Protobuf::Duration] # The number of seconds required to travel to the job location from the # query location. A duration of 0 seconds indicates that the job isn't # reachable within the requested duration, but was returned as part of an # expanded query. class CommuteInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#metadata ⇒ ::Google::Cloud::Talent::V4beta1::ResponseMetadata
Returns Additional information for the API invocation, such as the request tracking id.
731 732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 |
# File 'proto_docs/google/cloud/talent/v4beta1/job_service.rb', line 731 class SearchJobsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Job entry with metadata inside # {::Google::Cloud::Talent::V4beta1::SearchJobsResponse SearchJobsResponse}. # @!attribute [rw] job # @return [::Google::Cloud::Talent::V4beta1::Job] # Job resource that matches the specified # {::Google::Cloud::Talent::V4beta1::SearchJobsRequest SearchJobsRequest}. # @!attribute [rw] job_summary # @return [::String] # A summary of the job with core information that's displayed on the search # results listing page. # @!attribute [rw] job_title_snippet # @return [::String] # Contains snippets of text from the # {::Google::Cloud::Talent::V4beta1::Job#title Job.title} field most closely # matching a search query's keywords, if available. The matching query # keywords are enclosed in HTML bold tags. # @!attribute [rw] search_text_snippet # @return [::String] # Contains snippets of text from the # {::Google::Cloud::Talent::V4beta1::Job#description Job.description} and # similar fields that most closely match a search query's keywords, if # available. All HTML tags in the original fields are stripped when # returned in this field, and matching query keywords are enclosed in HTML # bold tags. # @!attribute [rw] commute_info # @return [::Google::Cloud::Talent::V4beta1::SearchJobsResponse::CommuteInfo] # Commute information which is generated based on specified # {::Google::Cloud::Talent::V4beta1::CommuteFilter CommuteFilter}. class MatchingJob include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Commute details related to this job. # @!attribute [rw] job_location # @return [::Google::Cloud::Talent::V4beta1::Location] # Location used as the destination in the commute calculation. # @!attribute [rw] travel_duration # @return [::Google::Protobuf::Duration] # The number of seconds required to travel to the job location from the # query location. A duration of 0 seconds indicates that the job isn't # reachable within the requested duration, but was returned as part of an # expanded query. class CommuteInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#next_page_token ⇒ ::String
Returns The token that specifies the starting position of the next page of results. This field is empty if there are no more results.
731 732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 |
# File 'proto_docs/google/cloud/talent/v4beta1/job_service.rb', line 731 class SearchJobsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Job entry with metadata inside # {::Google::Cloud::Talent::V4beta1::SearchJobsResponse SearchJobsResponse}. # @!attribute [rw] job # @return [::Google::Cloud::Talent::V4beta1::Job] # Job resource that matches the specified # {::Google::Cloud::Talent::V4beta1::SearchJobsRequest SearchJobsRequest}. # @!attribute [rw] job_summary # @return [::String] # A summary of the job with core information that's displayed on the search # results listing page. # @!attribute [rw] job_title_snippet # @return [::String] # Contains snippets of text from the # {::Google::Cloud::Talent::V4beta1::Job#title Job.title} field most closely # matching a search query's keywords, if available. The matching query # keywords are enclosed in HTML bold tags. # @!attribute [rw] search_text_snippet # @return [::String] # Contains snippets of text from the # {::Google::Cloud::Talent::V4beta1::Job#description Job.description} and # similar fields that most closely match a search query's keywords, if # available. All HTML tags in the original fields are stripped when # returned in this field, and matching query keywords are enclosed in HTML # bold tags. # @!attribute [rw] commute_info # @return [::Google::Cloud::Talent::V4beta1::SearchJobsResponse::CommuteInfo] # Commute information which is generated based on specified # {::Google::Cloud::Talent::V4beta1::CommuteFilter CommuteFilter}. class MatchingJob include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Commute details related to this job. # @!attribute [rw] job_location # @return [::Google::Cloud::Talent::V4beta1::Location] # Location used as the destination in the commute calculation. # @!attribute [rw] travel_duration # @return [::Google::Protobuf::Duration] # The number of seconds required to travel to the job location from the # query location. A duration of 0 seconds indicates that the job isn't # reachable within the requested duration, but was returned as part of an # expanded query. class CommuteInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#spell_correction ⇒ ::Google::Cloud::Talent::V4beta1::SpellingCorrection
Returns The spell checking result, and correction.
731 732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 |
# File 'proto_docs/google/cloud/talent/v4beta1/job_service.rb', line 731 class SearchJobsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Job entry with metadata inside # {::Google::Cloud::Talent::V4beta1::SearchJobsResponse SearchJobsResponse}. # @!attribute [rw] job # @return [::Google::Cloud::Talent::V4beta1::Job] # Job resource that matches the specified # {::Google::Cloud::Talent::V4beta1::SearchJobsRequest SearchJobsRequest}. # @!attribute [rw] job_summary # @return [::String] # A summary of the job with core information that's displayed on the search # results listing page. # @!attribute [rw] job_title_snippet # @return [::String] # Contains snippets of text from the # {::Google::Cloud::Talent::V4beta1::Job#title Job.title} field most closely # matching a search query's keywords, if available. The matching query # keywords are enclosed in HTML bold tags. # @!attribute [rw] search_text_snippet # @return [::String] # Contains snippets of text from the # {::Google::Cloud::Talent::V4beta1::Job#description Job.description} and # similar fields that most closely match a search query's keywords, if # available. All HTML tags in the original fields are stripped when # returned in this field, and matching query keywords are enclosed in HTML # bold tags. # @!attribute [rw] commute_info # @return [::Google::Cloud::Talent::V4beta1::SearchJobsResponse::CommuteInfo] # Commute information which is generated based on specified # {::Google::Cloud::Talent::V4beta1::CommuteFilter CommuteFilter}. class MatchingJob include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Commute details related to this job. # @!attribute [rw] job_location # @return [::Google::Cloud::Talent::V4beta1::Location] # Location used as the destination in the commute calculation. # @!attribute [rw] travel_duration # @return [::Google::Protobuf::Duration] # The number of seconds required to travel to the job location from the # query location. A duration of 0 seconds indicates that the job isn't # reachable within the requested duration, but was returned as part of an # expanded query. class CommuteInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#total_size ⇒ ::Integer
Returns The precise result count with limit 100,000.
731 732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 |
# File 'proto_docs/google/cloud/talent/v4beta1/job_service.rb', line 731 class SearchJobsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Job entry with metadata inside # {::Google::Cloud::Talent::V4beta1::SearchJobsResponse SearchJobsResponse}. # @!attribute [rw] job # @return [::Google::Cloud::Talent::V4beta1::Job] # Job resource that matches the specified # {::Google::Cloud::Talent::V4beta1::SearchJobsRequest SearchJobsRequest}. # @!attribute [rw] job_summary # @return [::String] # A summary of the job with core information that's displayed on the search # results listing page. # @!attribute [rw] job_title_snippet # @return [::String] # Contains snippets of text from the # {::Google::Cloud::Talent::V4beta1::Job#title Job.title} field most closely # matching a search query's keywords, if available. The matching query # keywords are enclosed in HTML bold tags. # @!attribute [rw] search_text_snippet # @return [::String] # Contains snippets of text from the # {::Google::Cloud::Talent::V4beta1::Job#description Job.description} and # similar fields that most closely match a search query's keywords, if # available. All HTML tags in the original fields are stripped when # returned in this field, and matching query keywords are enclosed in HTML # bold tags. # @!attribute [rw] commute_info # @return [::Google::Cloud::Talent::V4beta1::SearchJobsResponse::CommuteInfo] # Commute information which is generated based on specified # {::Google::Cloud::Talent::V4beta1::CommuteFilter CommuteFilter}. class MatchingJob include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Commute details related to this job. # @!attribute [rw] job_location # @return [::Google::Cloud::Talent::V4beta1::Location] # Location used as the destination in the commute calculation. # @!attribute [rw] travel_duration # @return [::Google::Protobuf::Duration] # The number of seconds required to travel to the job location from the # query location. A duration of 0 seconds indicates that the job isn't # reachable within the requested duration, but was returned as part of an # expanded query. class CommuteInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |